'use strict';
module.exports = function (grunt) {

  grunt.initConfig({
    watch: {
      // If any .less file changes in directory "build/less/" run the "less"-task.
      files: ["templates/web_style/build/less/*.less", "templates/web_style/build/less/skins/*.less", "templates/web_style/dist/js/app.js"],
      tasks: ["less", "uglify"]
    },
    // "less"-task configuration
    // This task will compile all less files upon saving to create both AdminLTE.css and AdminLTE.min.css
    less: {
      // Development not compressed
      development: {
        options: {
          // Whether to compress or not
          compress: false
        },
        files: {
          // compilation.css  :  source.less          
          "templates/web_style/dist/css/AdminLTE.css": "templates/web_style/build/less/AdminLTE.less",
          //Non minified skin files
          "templates/web_style/dist/css/skins/skin-blue.css": "templates/web_style/build/less/skins/skin-blue.less",
          "templates/web_style/dist/css/skins/skin-black.css": "templates/web_style/build/less/skins/skin-black.less",
          "templates/web_style/dist/css/skins/skin-yellow.css": "templates/web_style/build/less/skins/skin-yellow.less",
          "templates/web_style/dist/css/skins/skin-green.css": "templates/web_style/build/less/skins/skin-green.less",
          "templates/web_style/dist/css/skins/skin-red.css": "templates/web_style/build/less/skins/skin-red.less",
          "templates/web_style/dist/css/skins/skin-purple.css": "templates/web_style/build/less/skins/skin-purple.less",
          "templates/web_style/dist/css/skins/skin-blue-light.css": "templates/web_style/build/less/skins/skin-blue-light.less",
          "templates/web_style/dist/css/skins/skin-black-light.css": "templates/web_style/build/less/skins/skin-black-light.less",
          "templates/web_style/dist/css/skins/skin-yellow-light.css": "templates/web_style/build/less/skins/skin-yellow-light.less",
          "templates/web_style/dist/css/skins/skin-green-light.css": "templates/web_style/build/less/skins/skin-green-light.less",
          "templates/web_style/dist/css/skins/skin-red-light.css": "templates/web_style/build/less/skins/skin-red-light.less",
          "templates/web_style/dist/css/skins/skin-purple-light.css": "templates/web_style/build/less/skins/skin-purple-light.less",
          "templates/web_style/dist/css/skins/_all-skins.css": "templates/web_style/build/less/skins/_all-skins.less"
        }
      },
      // Production compresses version
      production: {
        options: {
          // Whether to compress or not          
          compress: true
        },
        files: {
          // compilation.css  :  source.less
          "templates/web_style/dist/css/AdminLTE.min.css": "templates/web_style/build/less/AdminLTE.less",
          // Skins minified
          "templates/web_style/dist/css/skins/skin-blue.min.css": "templates/web_style/build/less/skins/skin-blue.less",
          "templates/web_style/dist/css/skins/skin-black.min.css": "templates/web_style/build/less/skins/skin-black.less",
          "templates/web_style/dist/css/skins/skin-yellow.min.css": "templates/web_style/build/less/skins/skin-yellow.less",
          "templates/web_style/dist/css/skins/skin-green.min.css": "templates/web_style/build/less/skins/skin-green.less",
          "templates/web_style/dist/css/skins/skin-red.min.css": "templates/web_style/build/less/skins/skin-red.less",
          "templates/web_style/dist/css/skins/skin-purple.min.css": "templates/web_style/build/less/skins/skin-purple.less",
          "templates/web_style/dist/css/skins/skin-blue-light.min.css": "templates/web_style/build/less/skins/skin-blue-light.less",
          "templates/web_style/dist/css/skins/skin-black-light.min.css": "templates/web_style/build/less/skins/skin-black-light.less",
          "templates/web_style/dist/css/skins/skin-yellow-light.min.css": "templates/web_style/build/less/skins/skin-yellow-light.less",
          "templates/web_style/dist/css/skins/skin-green-light.min.css": "templates/web_style/build/less/skins/skin-green-light.less",
          "templates/web_style/dist/css/skins/skin-red-light.min.css": "templates/web_style/build/less/skins/skin-red-light.less",
          "templates/web_style/dist/css/skins/skin-purple-light.min.css": "templates/web_style/build/less/skins/skin-purple-light.less",
          "templates/web_style/dist/css/skins/_all-skins.min.css": "templates/web_style/build/less/skins/_all-skins.less"
        }
      }
    },
    // Uglify task info. Compress the js files.
    uglify: {
      options: {
        mangle: true,
        preserveComments: 'some'
      },
      my_target: {
        files: {
          'templates/web_style/dist/js/app.min.js': ['templates/web_style/dist/js/app.js']
        }
      }
    },
    // Build the documentation files
    includes: {
      build: {
        src: ['*.html'], // Source files 
        dest: 'templates/web_style/documentation/', // Destination directory 
        flatten: true,
        cwd: 'templates/web_style/documentation/build',
        options: {
          silent: true,
          includePath: 'templates/web_style/documentation/build/include'
        }
      }
    },
    cssjanus: {
      build: {
        files: {
          'templates/web_style/dist/css/AdminLTE-rtl.css': 'templates/web_style/dist/css/AdminLTE.css',
          'templates/web_style/dist/css/AdminLTE-rtl.min.css': 'templates/web_style/dist/css/AdminLTE.min.css',
          'templates/web_style/bootstrap/css/bootstrap-rtl.css': 'templates/web_style/bootstrap/css/bootstrap.css',
          'templates/web_style/bootstrap/css/bootstrap-rtl.min.css': 'templates/web_style/bootstrap/css/bootstrap.min.css'
        }
      }
    }
  });

  // Load all grunt tasks

  // LESS Compiler
  grunt.loadNpmTasks('grunt-contrib-less');
  // Watch File Changes
  grunt.loadNpmTasks('grunt-contrib-watch');
  // Compress JS Files
  grunt.loadNpmTasks('grunt-contrib-uglify');
  // Include Files Within HTML
  grunt.loadNpmTasks('grunt-includes');
  // Convert CSS to RTL
  grunt.loadNpmTasks('grunt-cssjanus');

  // The default task (running "grunt" in console) is "watch"
  grunt.registerTask('default', ['watch']);
};